pyhsm.debug_cmd.YHSM_Cmd_Monitor_Exit

Package pyhsm :: Module debug_cmd :: Class YHSM_Cmd_Monitor_Exit |
[frames] | no frames]

# Class YHSM_Cmd_Monitor_Exit

    cmd.YHSM_Cmd --+
                   |
                  YHSM_Cmd_Monitor_Exit

Send magics to YubiHSM in debug mode, and get it to exit to configuration mode again.

Instance Methods
__init__(self, stick, payload=`'````'`) The base class for all YSM_ commands. |
Inherited from `cmd.YHSM_Cmd`: `execute`, `parse_result`

Class Variables
Inherited from `cmd.YHSM_Cmd`: `executed`, `response_status`

Method Details

### __init__(self, stick, payload=`'````'`) (Constructor) |
The base class for all YSM_ commands. Parameters: `stick` - Reference to a YubiHSM `command` - The YSM_xxx command defined in pyhsm.defines. `payload` - a packed C struct, represented as a Python string Overrides: cmd.YHSM_Cmd.__init__ (inherited documentation)